
For CMCC  APP记录用的

```angular2
使用说明:

import  WZCMCCAPPLOGGER;

#可以根据具体情况 填写数据库的地址  默认  10.77.18.248,33889
# OA F8网络 10.77.18.248,33889
# 内网服务器 192.168.5.103
# DCN网  天山环境  10.212.194.197
WZCMCCAPPLOGGER.dbhost ='10.77.18.248,33889'

APPID ='22' #APPID 是 平台上申请的ID
WZCMCCAPPLOGGER.InsertLog(APPID);




```